local LibStub = LibStub
local AceAddon = LibStub("AceAddon-3.0")
local AceLocale = LibStub("AceLocale-3.0")
local AceDBOptions = LibStub("AceDBOptions-3.0")
local AceConfig = LibStub("AceConfig-3.0")
local AceConfigDialog = LibStub("AceConfigDialog-3.0")
local ControlPanel = AceAddon:GetAddon("ControlPanel")
local ControlPanel_Options = AceAddon:GetAddon("ControlPanel_Options")
local L = AceLocale:GetLocale("ControlPanel_Options")
local string_format = string.format

local post_process_anti_aliasings = {"None","FXAA Low","FXAA High","CMAA"}
local resample_qualities = {L["Bilinear"],L["Bicubic"]}
local screenshot_formats = { jpg = "jpg", jpeg = "jpeg", tga = "tga"}
local MSAA_qualities = { ["0"] = L["None"], ["1,0"]=L["Color 2x / Depth 2x"],["2,0"]=L["Color 4x / Depth 4x"],
				["2,1"]=L["Color 4x / Depth 8x"],["2,2"]=L["Color 4x / Depth 16x"],
				["3,0"]=L["Color 8x / Depth 8x"],["3,1"]=L["Color 8x / Depth 16x"],["3,2"]=L["Color 8x / Depth 32x"]}
local order = 0
local function get_order()
	local temp = order
	order = order +1
	return temp
end

			
local Graphics =
{
	name = L["Graphics"],
	type = "group",
	args =
	{
		hdPlayerModels =
		{
			order = get_order(),
			name = L["Show New Character Models"],
			desc = L["Check this to show new higher definition character models. (64-bit OS recommended)"],
			type = "toggle",
			set = function(info,val)
				ControlPanel:SetCVar("hdPlayerModels",val)
			end,
			get = function(info)
				return ControlPanel:GetCVarBool("hdPlayerModels")
			end,
			width = "full",
		},
		useUiScale =
		{
			order = get_order(),
			name = L["Use UI Scale"],
			desc = L["Check to use UI Scale Slider, uncheck to use the system default scale."],
			type = "toggle",
			set = function(info,val)
				ControlPanel:SetCVar("useUiScale",val)
			end,
			get = function(info)
				return ControlPanel:GetCVarBool("useUiScale")
			end,
		},
		uiScale =
		{
			order = get_order(),
			name = L["UI Scale"],
			desc = L["Changes the size of the game's user interface"],
			type = "range",
			min = 0,
			max = 10,
			set = function(info,val)
				ControlPanel:SetCVar("uiScale",val)
			end,
			get = function(info)
				return ControlPanel:GetCVar("uiScale")
			end,
		},
		Display =
		{
			order = get_order(),
			name = L["Display"],
			type = "group",
			args =
			{
				gxVSync =
				{
					order = get_order(),
					name = L["Vertical Sync"],
					desc = L["Synchronizes your framerate to some fraction of your monitor's refresh rate. Enable this if you see excessive screen tearing in game."],
					type = "toggle",
					set = function(info,val)
						ControlPanel:SetCVar("gxVSync",val)
					end,
					get = function(info)
						return ControlPanel:GetCVarBool("gxVSync")
					end,
				},
				gxTripleBuffer =
				{
					order = get_order(),
					name = L["Triple Buffering"],
					desc = L["Enables triple buffering of frames when vertical sync is enabled. Selecting triple buffering may even out frame rate spikes, but may also cause slight input lag."],
					type = "toggle",
					set = function(info,val)
						ControlPanel:SetCVar("gxTripleBuffer",val)
					end,
					get = function(info)
						return ControlPanel:GetCVarBool("gxTripleBuffer")
					end,
				},
				gxFixLag =
				{
					order = get_order(),
					name = L["Reduce Input Lag"],
					desc = L["Enabling this reduces user interface lag, but may drastically reduce frame rates."],
					type = "toggle",
					set = function(info,val)
						ControlPanel:SetCVar("gxFixLag",val)
					end,
					get = function(info)
						return ControlPanel:GetCVarBool("gxFixLag")
					end,
				},
				gxCursor = 
				{
					order = get_order(),
					name = L["Hardware Cursor"],
					desc = L["Enable this option for a more responsive cursor unless you have cursor problems."],
					type = "toggle",
					set = function(info,val)
						ControlPanel:SetCVar("gxCursor",val)
					end,
					get = function(info)
						return ControlPanel:GetCVarBool("gxCursor")
					end,
				},
				maxFPS = 
				{
					order = get_order(),
					name = L["Max Foreground FPS"],
					desc = L["Maximum framerate while running in the foreground\n\n(0 represents no limits)"],
					type = "range",
					min = 0,
					max = 200,
					set = function(info,val)
						ControlPanel:SetCVar("maxFPS",val)
					end,
					get = function(info)
						return ControlPanel:GetCVar("maxFPS")
					end,
				},
				maxFPSBk = 
				{
					order = get_order(),
					name = L["Max Background FPS"],
					desc = L["Maximum framerate while running in the background\n\n(0 represents no limits)"],
					type = "range",
					min = 0,
					max = 200,
					set = function(info,val)
						ControlPanel:SetCVar("maxFPSBk",val)
					end,
					get = function(info)
						return ControlPanel:GetCVar("maxFPSBk")
					end,
				},
			}
		},
		Anti_Aliasing =
		{
			order = get_order(),
			name = L["Anti-Aliasing"],
			desc = L["Anti-Aliasing is a technique to smooth out jaggy edges, especially at low resolutions, but can result in a slightly blurred image. Enabling Anti-Aliasing will reduce performance."],
			type = "group",
			args =
			{
				ffxAntiAliasingMode =
				{
					order = get_order(),
					name = L["Post-Process AA"],
					type = "select",
					values = post_process_anti_aliasings,
					set = function(info,val)
						ControlPanel:SetCVar("ffxAntiAliasingMode",val-1)
					end,
					get = function(info)
						return ControlPanel:GetCVar("ffxAntiAliasingMode")+1
					end,
					width = "full",
				},
				MSAA =
				{
					order = get_order(),
					name = "MSAA",
					desc = L["Multisample anti-aliasing"],
					type = "group",
					args =
					{
						MSAAQuality =
						{
							order = get_order(),
							name = "MSAA",
							desc = L["Sets the Multisample Anti-Aliasing mode. Both the number of color and depth samples can be specified."],
							type = "select",
							values = MSAA_qualities,
							set = function(info,val)
								ControlPanel:SetCVar("MSAAQuality",val)
							end,
							get = function(info)
								return ControlPanel:GetCVarString("MSAAQuality")
							end,
						},
						MSAAAlphaTest =
						{
							order = get_order(),
							name = L["Alpha-Test"],
							desc = L["Evaluates alpha-test operation at sample frequency rather than pixel frequency when MSAA is enabled."],
							type = "toggle",
							set = function(info,val)
								ControlPanel:SetCVar("MSAAAlphaTest",val)
							end,
							get = function(info)
								return ControlPanel:GetCVarBool("MSAAAlphaTest")
							end,
						}
					}
				},
				SSAA =
				{
					order = get_order(),
					name = "SSAA",
					desc = L["Supersampling Anti-aliasing"],
					type = "group",
					args =
					{
						RenderScale =
						{
							order = get_order(),
							name = L["Render Scale"],
							desc = L["Multiplier on display resolution for rendering the 3D World."],
							type = "range",
							min = 0,
							max = 2,
							set = function(info,val)
								ControlPanel:SetCVar("RenderScale",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("RenderScale")
							end,
						},
						ResampleQuality =
						{
							order = get_order(),
							name = L["Resample Quality"],
							desc = L["When using a Render Scale that is not 100%, this adjusts the quality of the filter to display resolution."],
							type = "select",
							values = resample_qualities,
							set = function(info,val)
								ControlPanel:SetCVar("ResampleQuality",val-1)
							end,
							get = function(info)
								return ControlPanel:GetCVar("ResampleQuality")+1
							end,
						}
					}
				},
			}
		},
		BasicSettings = 
		{
			order = get_order(),
			name = L["Basic Settings"],
			type = "group",
			args = 
			{
				graphicsQuality = 
				{
					order = get_order(),
					name = L["Graphics Quality"],
					type = "range",
					min = 0,
					max = 6,
					step = 1,
					set = function(info,val)
						ControlPanel:SetCVar("graphicsQuality",val)
						ControlPanel_Options:set_graphics_quality(val)
					end,
					get = function(info)
						return ControlPanel:GetCVar("graphicsQuality")
					end,
					width = "full",
				},
				Textures =
				{
					order = get_order(),
					name = L["Textures"],
					type = "group",
					args =
					{
						terrainmiplevel = 
						{
							order = get_order(),
							name = L["Terrain Blending"],
							desc = L["Controls the level of terrain blending. (Lower is better.) Increasing this may slightly improve performance."],
							type = "range",
							min = 0,
							max = 1,
							set = function(info,val)
								ControlPanel:SetCVar("terrainmiplevel",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("terrainmiplevel")
							end,
						},
						worldbasemip = 
						{
							order = get_order(),
							name = L["Environment and Character Resolution"],
							desc = L["Controls the level of environment and character resolution. (Lower is better.) Increasing this may slightly improve performance."],
							type = "range",
							min = 0,
							max = 2,
							set = function(info,val)
								ControlPanel:SetCVar("worldbasemip",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("worldbasemip")
							end,
						},
						textureFilteringMode = 
						{
							order = get_order(),
							name = L["Texture Filtering"],
							desc = L["Increases texture sharpness, particularly for textures view at an angle. Decrease to improve performance.\n\nBilinear(0)\nTrilinear(1)\n2x Anisotropic(2)\n4x Anisotropic(3)\n8x Anisotropic(4)\n16x Anisotropic(5)\n"],
							type = "range",
							min = 0,
							max = 5,
							step = 1,
							set = function(info,val)
								ControlPanel:SetCVar("textureFilteringMode",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("textureFilteringMode")
							end,
						},
						ProjectedTextures = 
						{
							order = get_order(),
							name = L["Projected Textures"],
							desc = L["Enables the projecting of textures to the environment. Disabling this may greatly improve performance."],
							type = "toggle",
							set = function(info,val)
								ControlPanel:SetCVar("ProjectedTextures",val)
							end,
							get = function(info)
								return ControlPanel:GetCVarBool("ProjectedTextures")
							end,
						}
					}
				},
				Environment =
				{
					order = get_order(),
					name = L["Environment"],
					type = "group",
					args = 
					{
						farclip = 
						{
							order = get_order(),
							name = L["View Distance"],
							desc = L["View distance controls how far you can see. Larger view distances require more memory and a faster processor."],
							type = "range",
							min = 0,
							max = 1300,
							step = 0.0001,
							set = function(info,val)
								ControlPanel:SetCVar("farclip",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("farclip")
							end,
						},
						environmentDetail = 
						{
							order = get_order(),
							name = L["Environment Detail"],
							desc = L["Controls how far you can see objects. Decrease to improve performance."],
							type = "range",
							min = 50,
							max = 150,
							set = function(info,val)
								ControlPanel:SetCVar("environmentDetail",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("environmentDetail")
							end,
						},
						groundEffectDensity = 
						{
							order = get_order(),
							name = L["Ground Clutter Density"],
							desc = L["Controls the density at which ground clutter items, like grass and foliage, are placed. Decrease to improve performance."],
							type = "range",
							min = 16,
							max = 128,
							set = function(info,val)
								ControlPanel:SetCVar("groundEffectDensity",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("groundEffectDensity")
							end,
						},
						groundEffectDist = 
						{
							order = get_order(),
							name = L["Ground Clutter Distance"],
							desc = L["Controls the distance at which ground clutter items, like grass and foliage, are placed. Decrease to improve performance."],
							type = "range",
							min = 50,
							max = 260,
							set = function(info,val)
								ControlPanel:SetCVar("groundEffectDist",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("groundEffectDist")
							end,
						},
					}
				},
				Effects =
				{
					order = get_order(),
					name = L["Effects"],
					type = "group",
					args = 
					{
						shadowMode = 
						{
							order = get_order(),
							name = L["Shadow Quality"],
							desc = L["Controls both the method and quality of shadows. Decreasing this may greatly improve performance."],
							type = "range",
							min = 0,
							max = 4,
							step = 1,
							set = function(info,val)
								ControlPanel:SetCVar("shadowMode",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("shadowMode")
							end,
						},
						waterDetail = 
						{
							order = get_order(),
							name = L["Liquid Detail"],
							desc = L["Controls the rendering quality of liquid. Decreasing this may improve performance.\n\nLow(0): Animated Liquid textures, texture based ripples and no reflection.\n\nFair(1): Normalmap liquid textures, texture based ripples and sky reflection.\n\nGood(2): Normalmap liquid textures, procedural ripples and screen-based reflection.\n\nUltra(3): Normalmap liquid textures, procedural ripples and full reflection."],
							type = "range",
							min = 0,
							max = 3,
							step = 1,
							set = function(info,val)
								ControlPanel:SetCVar("waterDetail",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("waterDetail")
							end,
						},
						sunShafts = 
						{
							order = get_order(),
							name = L["Sunshafts"],
							desc = L["Controls the method and quality used to display sunshafts and glare effects. Disabling this setting may improve performance.\n\nDisabled(0): Traditional sunshafts and glave.\n\nLow(1): Depth-based sunshafts and glare.\n\nHigh(2): Depth-based sunshafts and glare with improved sampling to reduce anti-aliasing."],
							type = "range",
							min = 0,
							max = 2,
							step = 1,
							set = function(info,val)
								ControlPanel:SetCVar("sunShafts",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("sunShafts")
							end,
						},
						particleDensity = 
						{
							order = get_order(),
							name = L["Particle Density"],
							desc = L["Controls the number of particles used in effects caused by spells, fires, etc. Decrease to improve performance."],
							type = "range",
							min = 10,
							max = 100,
							set = function(info,val)
								ControlPanel:SetCVar("particleDensity",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("particleDensity")
							end,
						},
						SSAO = 
						{
							order = get_order(),
							name = L["SSAO"],
							desc = L["Controls the rendering quality of the advanced lighting effects. Decreasing this may greatly improve performance."],
							type = "range",
							min = 0,
							max = 3,
							step = 1,
							set = function(info,val)
								ControlPanel:SetCVar("SSAO",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("SSAO")
							end,
						},
						lightmode = 
						{
							order = get_order(),
							name = L["Lightning Quality"],
							desc = L["Controls both the method and quality of lighting. Decreasing this may improve performance."],
							type = "range",
							min = 0,
							max = 2,
							step = 1,
							set = function(info,val)
								ControlPanel:SetCVar("lightmode",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("lightmode")
							end,
						},
						DepthBasedOpacity = 
						{
							order = get_order(),
							name = L["Particle Depth Fading"],
							type = "toggle",
							set = function(info,val)
								ControlPanel:SetCVar("DepthBasedOpacity",val)
							end,
							get = function(info)
								return ControlPanel:GetCVarBool("DepthBasedOpacity")
							end,
						},
						refraction = 
						{
							order = get_order(),
							name = L["Refraction"],
							type = "range",
							min = 0,
							max = 2,
							step = 1,
							set = function(info,val)
								ControlPanel:SetCVar("refraction",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("refraction")
							end,
						},
						outlineEngineMode = 
						{
							order = get_order(),
							name = L["Outline Mode"],
							desc = L["Controls whether the selection outline effect is allowed. See the interface Display panel for more options."],
							type = "toggle",
							set = function(info,val)
								ControlPanel:SetCVar("outlineEngineMode",val)
							end,
							get = function(info)
								return ControlPanel:GetCVarBool("outlineEngineMode")
							end,
						}
					}
				}
			}
		},
		
		RaidAndBattlegroundSettings = 
		{
			order = get_order(),
			name = L["Raid And Battleground Settings"],
			type = "group",
			args = 
			{
				graphicsQuality = 
				{
					order = get_order(),
					name = L["Graphics Quality"],
					type = "range",
					min = 0,
					max = 6,
					step = 1,
					set = function(info,val)
						ControlPanel:SetCVar("RAIDgraphicsQuality",val)
						ControlPanel_Options:set_raid_graphics_quality(val)
					end,
					get = function(info)
						return ControlPanel:GetCVar("RAIDgraphicsQuality")
					end,
					width = "full",
				},
				RAIDsettingsEnabled =
				{
					order = get_order(),
					name = L["Enable"],
					desc = L["Check this option to enable alternate graphic setting for Raids and Battlegrounds"],
					type = "toggle",
					set = function(info,val)
						ControlPanel:SetCVar("RAIDsettingsEnabled",val)
					end,
					get = function(info)
						return ControlPanel:GetCVarBool("RAIDsettingsEnabled")
					end,
					width = "full",
				},
				Textures =
				{
					order = get_order(),
					name = L["Textures"],
					type = "group",
					args =
					{
						terrainmiplevel = 
						{
							order = get_order(),
							name = L["Terrain Blending"],
							desc = L["Controls the level of terrain blending. (Lower is better.) Increasing this may slightly improve performance."],
							type = "range",
							min = 0,
							max = 1,
							set = function(info,val)
								ControlPanel:SetCVar("RAIDerrainmiplevel",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("RAIDterrainmiplevel")
							end,
						},
						worldbasemip = 
						{
							order = get_order(),
							name = L["Environment and Character Resolution"],
							desc = L["Controls the level of environment and character resolution. (Lower is better.) Increasing this may slightly improve performance."],
							type = "range",
							min = 0,
							max = 2,
							set = function(info,val)
								ControlPanel:SetCVar("RAIDworldbasemip",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("RAIDworldbasemip")
							end,
						},
						textureFilteringMode = 
						{
							order = get_order(),
							name = L["Texture Filtering"],
							desc = L["Increases texture sharpness, particularly for textures view at an angle. Decrease to improve performance.\n\nBilinear(0)\nTrilinear(1)\n2x Anisotropic(2)\n4x Anisotropic(3)\n8x Anisotropic(4)\n16x Anisotropic(5)\n"],
							type = "range",
							min = 0,
							max = 5,
							step = 1,
							set = function(info,val)
								ControlPanel:SetCVar("RAIDtextureFilteringMode",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("RAIDtextureFilteringMode")
							end,
						},
						ProjectedTextures = 
						{
							order = get_order(),
							name = L["Projected Textures"],
							desc = L["Enables the projecting of textures to the environment. Disabling this may greatly improve performance."],
							type = "toggle",
							set = function(info,val)
								ControlPanel:SetCVar("RAIDProjectedTextures",val)
							end,
							get = function(info)
								return ControlPanel:GetCVarBool("RAIDProjectedTextures")
							end,
						}
					}
				},
				Environment =
				{
					order = get_order(),
					name = L["Environment"],
					type = "group",
					args = 
					{
						farclip = 
						{
							order = get_order(),
							name = L["View Distance"],
							desc = L["View distance controls how far you can see. Larger view distances require more memory and a faster processor."],
							type = "range",
							min = 0,
							max = 1300,
							step = 0.0001,
							set = function(info,val)
								ControlPanel:SetCVar("RAIDfarclip",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("RAIDfarclip")
							end,
						},
						environmentDetail = 
						{
							order = get_order(),
							name = L["Environment Detail"],
							desc = L["Controls how far you can see objects. Decrease to improve performance."],
							type = "range",
							min = 50,
							max = 150,
							set = function(info,val)
								ControlPanel:SetCVar("RAIDenvironmentDetail",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("RAIDenvironmentDetail")
							end,
						},
						groundEffectDensity = 
						{
							order = get_order(),
							name = L["Ground Clutter Density"],
							desc = L["Controls the density at which ground clutter items, like grass and foliage, are placed. Decrease to improve performance."],
							type = "range",
							min = 16,
							max = 128,
							set = function(info,val)
								ControlPanel:SetCVar("RAIDgroundEffectDensity",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("RAIDgroundEffectDensity")
							end,
						},
						groundEffectDist = 
						{
							order = get_order(),
							name = L["Ground Clutter Distance"],
							desc = L["Controls the distance at which ground clutter items, like grass and foliage, are placed. Decrease to improve performance."],
							type = "range",
							min = 50,
							max = 260,
							set = function(info,val)
								ControlPanel:SetCVar("RAIDgroundEffectDist",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("RAIDgroundEffectDist")
							end,
						},
					}
				},
				Effects =
				{
					order = get_order(),
					name = L["Effects"],
					type = "group",
					args = 
					{
						shadowMode = 
						{
							order = get_order(),
							name = L["Shadow Quality"],
							desc = L["Controls both the method and quality of shadows. Decreasing this may greatly improve performance."],
							type = "range",
							min = 0,
							max = 4,
							step = 1,
							set = function(info,val)
								ControlPanel:SetCVar("RAIDshadowMode",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("RAIDshadowMode")
							end,
						},
						waterDetail = 
						{
							order = get_order(),
							name = L["Liquid Detail"],
							desc = L["Controls the rendering quality of liquid. Decreasing this may improve performance.\n\nLow(0): Animated Liquid textures, texture based ripples and no reflection.\n\nFair(1): Normalmap liquid textures, texture based ripples and sky reflection.\n\nGood(2): Normalmap liquid textures, procedural ripples and screen-based reflection.\n\nUltra(3): Normalmap liquid textures, procedural ripples and full reflection."],
							type = "range",
							min = 0,
							max = 3,
							step = 1,
							set = function(info,val)
								ControlPanel:SetCVar("RAIDwaterDetail",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("RAIDwaterDetail")
							end,
						},
						sunShafts = 
						{
							order = get_order(),
							name = L["Sunshafts"],
							desc = L["Controls the method and quality used to display sunshafts and glare effects. Disabling this setting may improve performance.\n\nDisabled(0): Traditional sunshafts and glave.\n\nLow(1): Depth-based sunshafts and glare.\n\nHigh(2): Depth-based sunshafts and glare with improved sampling to reduce anti-aliasing."],
							type = "range",
							min = 0,
							max = 2,
							step = 1,
							set = function(info,val)
								ControlPanel:SetCVar("RAIDsunShafts",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("RAIDsunShafts")
							end,
						},
						particleDensity = 
						{
							order = get_order(),
							name = L["Particle Density"],
							desc = L["Controls the number of particles used in effects caused by spells, fires, etc. Decrease to improve performance."],
							type = "range",
							min = 10,
							max = 100,
							set = function(info,val)
								ControlPanel:SetCVar("RAIDparticleDensity",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("RAIDparticleDensity")
							end,
						},
						SSAO = 
						{
							order = get_order(),
							name = L["SSAO"],
							desc = L["Controls the rendering quality of the advanced lighting effects. Decreasing this may greatly improve performance."],
							type = "range",
							min = 0,
							max = 3,
							step = 1,
							set = function(info,val)
								ControlPanel:SetCVar("RAIDSSAO",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("RAIDSSAO")
							end,
						},
						lightmode = 
						{
							order = get_order(),
							name = L["Lightning Quality"],
							desc = L["Controls both the method and quality of lighting. Decreasing this may improve performance."],
							type = "range",
							min = 0,
							max = 2,
							step = 1,
							set = function(info,val)
								ControlPanel:SetCVar("RAIDlightmode",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("RAIDlightmode")
							end,
						},
						DepthBasedOpacity = 
						{
							order = get_order(),
							name = L["Particle Depth Fading"],
							type = "toggle",
							set = function(info,val)
								ControlPanel:SetCVar("RAIDDepthBasedOpacity",val)
							end,
							get = function(info)
								return ControlPanel:GetCVarBool("RAIDDepthBasedOpacity")
							end,
						},
						refraction = 
						{
							order = get_order(),
							name = L["Refraction"],
							type = "range",
							min = 0,
							max = 2,
							step = 1,
							set = function(info,val)
								ControlPanel:SetCVar("RAIDrefraction",val)
							end,
							get = function(info)
								return ControlPanel:GetCVar("RAIDrefraction")
							end,
						},
						outlineEngineMode = 
						{
							order = get_order(),
							name = L["Outline Mode"],
							desc = L["Controls whether the selection outline effect is allowed. See the interface Display panel for more options."],
							type = "toggle",
							set = function(info,val)
								ControlPanel:SetCVar("RAIDoutlineEngineMode",val)
							end,
							get = function(info)
								return ControlPanel:GetCVarBool("RAIDoutlineEngineMode")
							end,
						}
					}
				}
			}
		},

		Screenshot =
		{
			order = get_order(),
			name = L["Screenshot"],
			type = "group",
			args = 
			{
				screenshotFormat =
				{
					order = get_order(),
					name = L["Format"],
					type = "select",
					values = screenshot_formats,
					set = function(info,val)
						ControlPanel:SetCVar("screenshotFormat",val)
					end,
					get = function(info)
						return ControlPanel:GetCVarString("screenshotFormat")
					end
				},
				screenshotQuality =
				{
					order = get_order(),
					name = L["Quality"],
					desc = L["Note this option only affects JPEG screenshots (TGA screenshots always use lossless quality)."],
					type = "range",
					min = 1,
					max =10,
					step = 1,
					set = function(info,val)
						ControlPanel:SetCVar("screenshotQuality",val)
					end,
					get = function(info)
						return ControlPanel:GetCVar("screenshotQuality")
					end,
				},
			}
		}
	}
}

ControlPanel_Options:push("Graphics",Graphics)